@@ -28,14 +28,13 @@ def _is_lock_taken(lock_name: str) -> bool:
     try:
         # This is a special case, this will only happen if the lock is already taken,
         # or something has crashed hard and the lock has been manually reset, wrong
-        lock = open(lock_name, "r")
-        lock_content = lock.read()
-        lock.close()
-        # if there is no content in the lock file, or the content is all
-        # whitespaces the lock isn't taken
-        locked: bool = not ((not lock_content) or lock_content.isspace())
+        with open(lock_name, "r") as lock:
+            lock_content = lock.read()
+
+            # if there is no content in the lock file, or the content is all
+            # whitespaces the lock isn't taken
+            locked: bool = not ((not lock_content) or lock_content.isspace())
 
-        print(locked)
     except FileNotFoundError:
         # This is the normal case
         return False
@@ -52,18 +51,24 @@ def notify_prometheus(lock_file_name: str, lock_conflict: bool) -> None:
     log = structlog.getLogger()
     job_name = f"lock_conflict_{lock_file_name}"
     registry = CollectorRegistry()
-    g = Gauge(
-        name=job_name,
-        documentation="Lock conflict, time is from last successful run",
+
+    g_time = Gauge(
+        name="mo_end_time", documentation="Unixtime for job end time", registry=registry
+    )
+    g_time.set_to_current_time()
+
+    g_ret_code = Gauge(
+        name="mo_return_code",
+        documentation="Return code of job",
         registry=registry,
     )
     if not lock_conflict:
-        g.set_to_current_time()
-        g.set(0)
+        g_ret_code.set(0)
     else:
-        g.inc(1)
+        g_ret_code.inc(1)
+
     try:
-        prometheus_client.exposition.push_to_gateway(
+        prometheus_client.exposition.pushadd_to_gateway(
             gateway="localhost:9091", job=job_name, registry=registry
         )
     except urllib.error.URLError as ue:
